Bug 7092 - linux-yocto: improve do_patch performance
Summary: linux-yocto: improve do_patch performance
Status: RESOLVED FIXED
Alias: None
Product: OE-Core
Classification: Build System, Metadata & Runtime
Component: kernel (show other bugs)
Version: 1.8
Hardware: x86 Multiple
: Medium enhancement
Target Milestone: 1.8 M3
Assignee: Bruce Ashfield
QA Contact:
URL:
Whiteboard:
Depends on:
Blocks:
 
Reported: 2014-12-19 16:14 UTC by Bruce Ashfield
Modified: 2015-02-17 21:10 UTC (History)
3 users (show)

See Also:
OS type for building Yocto: ---
Type of Regression: ---
Verified:
Documentation change: No (bug/feature does not impact docs)


Attachments

Note You need to log in before you can comment on or make changes to this bug.
Description Bruce Ashfield 2014-12-19 16:14:45 UTC
When gathering and validating the patches during do_patch() linux-yocto consumes
time with sanity checks and per-patch validation. In the majority of cases, this is
unnecessary and can be short cut / optimized.

As part of the developer experience efforts, we can make the optimized case be the
default.
Comment 1 Bruce Ashfield 2015-01-27 16:16:02 UTC
We have patches that improve the patch phase by 20 seconds, and it should be 
constant no matter how large the queue of patches to be validated. More testing
and they'll be submitted.
Comment 2 Bruce Ashfield 2015-02-17 21:10:02 UTC
The do_patch time improvements have been merged to oe-core. This is closed for 1.8.
Future work will happen under new bugzilla entries.